@@ -1785,7 +1785,7 @@ srl_get_context (Accessible *acc)
 	    Accessible_unref (acc);
 	    acc = parent;
 	    role = Accessible_getRole (acc);
-	    if (role == SPI_ROLE_EMBEDDED)
+	    if (role == SPI_ROLE_EMBEDDED || role == SPI_ROLE_TOOL_BAR)
 	    {
 		context = acc;
 		Accessible_ref (context);
@@ -2176,3 +2176,11 @@ srl_unwatch_all_objects ()
 	Accessible_unref (srl_watched_acc);
     srl_watched_acc = NULL;
 }
+
+gboolean
+srl_is_object_watched (SRObject *obj)
+{
+    srl_assert (obj);
+
+    return sro_get_acc (obj) == srl_watched_acc;
+}
